@@ -9,10 +9,11 @@
 ## Last update Wed 28 Jun 2017 11:20:48 AM CEST pret
 ##
 
-cd $(AUTOPKGTEST_TMP)
+cd $AUTOPKGTEST_TMP
 
-bdfproxy &
+/usr/bin/bdf_proxy &
 
 # by default, bdfproxy listen on port 8080
 netstat -laputen 2>/dev/null|grep 8080
 
+pkill bdf_proxy;
